@@ -142,5 +142,8 @@ from chb._utils import get_time_str
 from chb._utils import MutilThreadReader
 from chb._utils import Tableprint
 from chb._utils import bar
-from chb._utils import time_cost
+from chb._utils import bar2
+from chb._utils import getsizeof
+from chb._utils import getdeepsizeof
 from chb._utils import Timer
+from chb._utils import GetFirstLetter
