@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 from __future__ import print_function
-from ._imports import *
+
 from collections.abc import Iterable
 import pytz
 import xpinyin
@@ -8,14 +8,14 @@ from threading import Thread
 from chb._log import Log
 from datetime import datetime
 
-from sys import getsizeof, stderr
+import sys
 from itertools import chain
 from collections import deque
 try:
     from reprlib import repr
 except ImportError:
     pass
-
+from chb._imports import *
 log = Log(message_only=True)()
 
 def set_device(cuda_index=0):
@@ -277,7 +277,7 @@ def getdeepsizeof(o, handlers={}, verbose=False):
         if id(o) in seen:  # do not double count the same object
             return 0
         seen.add(id(o))
-        s = getsizeof(o, default_size)
+        s = sys.getsizeof(o, default_size)
         for typ, handler in all_handlers.items():
             if isinstance(o, typ):
                 s += sum(map(sizeof, handler(o)))
@@ -458,7 +458,7 @@ class Timer:
         :param end_format_str: 输出时间字符串的格式，默认为 %Y-%m-%d %H:%M:%S
         :return: 时间字符串，格式通过format_
         """
-        start_date = datetime.strptime(start_date_str, start_format_str)
+        start_date = datetime.datetime.strptime(start_date_str, start_format_str)
         days = datetime.timedelta(days=days, seconds=seconds, minutes=minutes, hours=hours, weeks=weeks)
         end_date = start_date + days
         return end_date.strftime(end_format_str)
@@ -471,7 +471,7 @@ class Timer:
         :param format_str: 字符型， string参数的时间格式
         :return:  datatime类 实例对象
         """
-        return datetime.strptime(string, format_str)
+        return datetime.datetime.strptime(string, format_str)
 
     @staticmethod
     def datetime2str(dt, format_str='%Y-%m-%d %H:%M:%S'):
@@ -502,7 +502,7 @@ class Timer:
             # 抛出异常，提示无效的时区参数
             raise ValueError('Invalid timezone parameter. Must be UTC or CST.')
         # 将时间戳转换为带有时区的datetime对象
-        dt = datetime.fromtimestamp(stamp, tz=timezone)
+        dt = datetime.datetime.fromtimestamp(stamp, tz=timezone)
         # 返回datetime对象
         return dt
 
@@ -531,7 +531,7 @@ class Timer:
         else:
             dt = dt.astimezone(timezone)
         # 将datetime对象转换为时间戳（秒）
-        ts = datetime.timestamp(dt)
+        ts = datetime.datetime.timestamp(dt)
         # 四舍五入并转换为整数
         ts = int(round(ts))
         # 返回时间戳
@@ -545,7 +545,7 @@ class Timer:
         :param format_str: 字符型， string参数的时间格式
         :return:  整型时间戳
         """
-        return datetime.strptime(string1, '%Y-%m-%d %H:%M:%S') - datetime.strptime(string2, '%Y-%m-%d %H:%M:%S')
+        return datetime.datetime.strptime(string1, '%Y-%m-%d %H:%M:%S') - datetime.datetime.strptime(string2, '%Y-%m-%d %H:%M:%S')
 
 class GetFirstLetter(object):
     def is_contain_chinese(self, check_str):
@@ -605,3 +605,14 @@ class Open:
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         self.file_handle.close()
+
+    def readline(self):
+        while True:
+            line = self.file_handle.readline()
+            if not line:
+                break
+            yield line
+
+
+if __name__=='__main__':
+    print(Timer.datebetween('2022-01-01 00:00:00', '2022-01-04 00:00:00'))
